==> haskell-warp-tls-3.2.4-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-warp-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp-tls
version: 3.2.4
id: warp-tls-3.2.4-4OkyktqoP0r5g9HaB9g6Z6
key: warp-tls-3.2.4-4OkyktqoP0r5g9HaB9g6Z6
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: HTTP over TLS support for Warp via the TLS package
description:
    SSLv1 and SSLv2 are obsoleted by IETF.
    We should use TLS 1.2 (or TLS 1.1 or TLS 1.0 if necessary).
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.
category: Web, Yesod
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Network.Wai.Handler.WarpTLS
abi: 71f6ed953bc1b77d20190092bdbb0532
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/warp-tls-3.2.4
library-dirs: /usr/lib/ghc-8.2.1/site-local/warp-tls-3.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/warp-tls-3.2.4
hs-libraries: HSwarp-tls-3.2.4-4OkyktqoP0r5g9HaB9g6Z6
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    cryptonite-0.24-1eRB8onf2x1HH5rI2M7djb
    data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp
    network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx
    streaming-commons-0.1.18-DO9CaqvVOYhDrA5bma8vy4
    tls-1.4.0-59P2QRjXtqq6Og4afpGkIb
    tls-session-manager-0.0.0.1-59cryDsGkJ71LtGIGBQn4y
    wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS
    warp-3.2.13-3jx9zQcd6WNir1vDKlmcC
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             cryptonite-0.24-1eRB8onf2x1HH5rI2M7djb=d02ab198c5c49165db40ebdbd565d8e9
             data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp=b4f1dc33e75c56b9a2dc645c2701b72a
             network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx=06cb668c0e9e66cc22d17c21c1fa2e38
             streaming-commons-0.1.18-DO9CaqvVOYhDrA5bma8vy4=a8e985bc4396c13c01f1c6615bbcad37
             tls-1.4.0-59P2QRjXtqq6Og4afpGkIb=092d35d636e8b457e2c5a2b2f04fae86
             tls-session-manager-0.0.0.1-59cryDsGkJ71LtGIGBQn4y=a84a5aa7305f5aca9b527f9571183673
             wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS=9c6a864f8fa1a2052bc8fe34ff093e3a
             warp-3.2.13-3jx9zQcd6WNir1vDKlmcC=ea0f27d62293857d4a9cd6aaf3154b9b
haddock-interfaces: /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html: /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-tls-3.2.4-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-warp-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp-tls
version: 3.2.4
id: warp-tls-3.2.4-4n9qzYFFxQeL0D8sVgceNc
key: warp-tls-3.2.4-4n9qzYFFxQeL0D8sVgceNc
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: HTTP over TLS support for Warp via the TLS package
description:
    SSLv1 and SSLv2 are obsoleted by IETF.
    We should use TLS 1.2 (or TLS 1.1 or TLS 1.0 if necessary).
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.
category: Web, Yesod
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Network.Wai.Handler.WarpTLS
abi: 7902e5b5b67e1d82bd7aee3caee0a856
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/warp-tls-3.2.4
library-dirs: /usr/lib/ghc-8.2.1/site-local/warp-tls-3.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/warp-tls-3.2.4
hs-libraries: HSwarp-tls-3.2.4-4n9qzYFFxQeL0D8sVgceNc
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    cryptonite-0.24-1eRB8onf2x1HH5rI2M7djb
    data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp
    network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx
    streaming-commons-0.1.18-DO9CaqvVOYhDrA5bma8vy4
    tls-1.4.0-59P2QRjXtqq6Og4afpGkIb
    tls-session-manager-0.0.0.1-59cryDsGkJ71LtGIGBQn4y
    wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS
    warp-3.2.13-3xPm02vnKdc1gViEPlMAOd
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             cryptonite-0.24-1eRB8onf2x1HH5rI2M7djb=d02ab198c5c49165db40ebdbd565d8e9
             data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp=b4f1dc33e75c56b9a2dc645c2701b72a
             network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx=06cb668c0e9e66cc22d17c21c1fa2e38
             streaming-commons-0.1.18-DO9CaqvVOYhDrA5bma8vy4=a8e985bc4396c13c01f1c6615bbcad37
             tls-1.4.0-59P2QRjXtqq6Og4afpGkIb=092d35d636e8b457e2c5a2b2f04fae86
             tls-session-manager-0.0.0.1-59cryDsGkJ71LtGIGBQn4y=a84a5aa7305f5aca9b527f9571183673
             wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS=9c6a864f8fa1a2052bc8fe34ff093e3a
             warp-3.2.13-3xPm02vnKdc1gViEPlMAOd=5bd7d4049d6e883a947d614b7470c980
haddock-interfaces: /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html: /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
